@@ -150,11 +150,11 @@ from ._jsii import *
 import aws_cdk.aws_ec2
 import aws_cdk.aws_elasticache
 import aws_cdk.aws_lambda
-import aws_cdk.core
+import constructs
 
 
 class LambdaToElasticachememcached(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-elasticachememcached.LambdaToElasticachememcached",
 ):
@@ -164,7 +164,7 @@ class LambdaToElasticachememcached(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         cache_endpoint_environment_variable_name: typing.Optional[builtins.str] = None,
